==> haskell-commonmark-extensions-0.2.5.5-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commonmark-extensions
version:              0.2.5.5
visibility:           public
id:                   commonmark-extensions-0.2.5.5-7sX8AsJduk1J0Bz8VUqB48
key:                  commonmark-extensions-0.2.5.5-7sX8AsJduk1J0Bz8VUqB48
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Pure Haskell commonmark parser.
description:
    This library provides some useful extensions to core commonmark
    syntax: smart quotes, definition lists, tables, footnotes, math,
    and more.

category:             Text
abi:                  06f8df0ddab58067df11b612714d7990
exposed:              True
exposed-modules:
    Commonmark.Extensions Commonmark.Extensions.Alerts
    Commonmark.Extensions.Attributes
    Commonmark.Extensions.AutoIdentifiers
    Commonmark.Extensions.Autolink Commonmark.Extensions.DefinitionList
    Commonmark.Extensions.Emoji Commonmark.Extensions.FancyList
    Commonmark.Extensions.Footnote Commonmark.Extensions.HardLineBreaks
    Commonmark.Extensions.ImplicitHeadingReferences
    Commonmark.Extensions.Math Commonmark.Extensions.PipeTable
    Commonmark.Extensions.RebaseRelativePaths
    Commonmark.Extensions.Smart Commonmark.Extensions.Strikethrough
    Commonmark.Extensions.Subscript Commonmark.Extensions.Superscript
    Commonmark.Extensions.TaskList Commonmark.Extensions.Wikilinks

import-dirs:          /usr/lib/ghc-9.4.8/site-local/commonmark-extensions-0.2.5.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/commonmark-extensions-0.2.5.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/commonmark-extensions-0.2.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark-extensions
hs-libraries:         HScommonmark-extensions-0.2.5.5-7sX8AsJduk1J0Bz8VUqB48
depends:
    base-4.17.2.1 commonmark-0.2.6-vzpQmHkDiqnPJoe9xP0b
    containers-0.6.7 emojis-0.1.4.1-GsPqDvY8sjR97EGs21xpKB
    filepath-1.4.2.2 network-uri-2.6.4.2-4dyZiFqUsAXDJ8mS3jtc8B
    parsec-3.1.16.1 text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-extensions/html/commonmark-extensions.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-extensions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-commonmark-extensions-0.2.5.5-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commonmark-extensions
version:              0.2.5.5
visibility:           public
id:                   commonmark-extensions-0.2.5.5-71xej1gDsH05pVchRtapQA
key:                  commonmark-extensions-0.2.5.5-71xej1gDsH05pVchRtapQA
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Pure Haskell commonmark parser.
description:
    This library provides some useful extensions to core commonmark
    syntax: smart quotes, definition lists, tables, footnotes, math,
    and more.

category:             Text
abi:                  cc378338a04a6766176df0e1d1f0257e
exposed:              True
exposed-modules:
    Commonmark.Extensions Commonmark.Extensions.Alerts
    Commonmark.Extensions.Attributes
    Commonmark.Extensions.AutoIdentifiers
    Commonmark.Extensions.Autolink Commonmark.Extensions.DefinitionList
    Commonmark.Extensions.Emoji Commonmark.Extensions.FancyList
    Commonmark.Extensions.Footnote Commonmark.Extensions.HardLineBreaks
    Commonmark.Extensions.ImplicitHeadingReferences
    Commonmark.Extensions.Math Commonmark.Extensions.PipeTable
    Commonmark.Extensions.RebaseRelativePaths
    Commonmark.Extensions.Smart Commonmark.Extensions.Strikethrough
    Commonmark.Extensions.Subscript Commonmark.Extensions.Superscript
    Commonmark.Extensions.TaskList Commonmark.Extensions.Wikilinks

import-dirs:          /usr/lib/ghc-9.4.8/site-local/commonmark-extensions-0.2.5.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/commonmark-extensions-0.2.5.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/commonmark-extensions-0.2.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark-extensions
hs-libraries:         HScommonmark-extensions-0.2.5.5-71xej1gDsH05pVchRtapQA
depends:
    base-4.17.2.1 commonmark-0.2.6-GF8oaxHu1yIJs8o2pZcx
    containers-0.6.7 emojis-0.1.4.1-GsPqDvY8sjR97EGs21xpKB
    filepath-1.4.2.2 network-uri-2.6.4.2-yi3MP3fDM2AtnMkY6gtjY
    parsec-3.1.16.1 text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-extensions/html/commonmark-extensions.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-extensions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
